[devhelp] Rename dh_free_resources() to dh_finalize()
- From: Sébastien Wilmet <swilmet src gnome org>
- To: commits-list gnome org
- Cc:
- Subject: [devhelp] Rename dh_free_resources() to dh_finalize()
- Date: Sat, 29 Jul 2017 09:44:16 +0000 (UTC)
commit 4b2592c8498ba18ea54a78b8ae6cb3c03b573a9f
Author: Sébastien Wilmet <swilmet gnome org>
Date: Sat Jul 29 11:36:48 2017 +0200
Rename dh_free_resources() to dh_finalize()
init/finalize are more familiar names.
dh_free_resources() was a new function added during this development
cycle, so it's fine to rename it. And anyway it is not yet used by
gnome-builder or Anjuta.
docs/reference/devhelp-sections.txt | 2 +-
src/dh-init.c | 6 +++---
src/dh-init.h | 4 ++--
src/dh-main.c | 2 +-
4 files changed, 7 insertions(+), 7 deletions(-)
---
diff --git a/docs/reference/devhelp-sections.txt b/docs/reference/devhelp-sections.txt
index cf65125..7a6ebfe 100644
--- a/docs/reference/devhelp-sections.txt
+++ b/docs/reference/devhelp-sections.txt
@@ -4,7 +4,7 @@
<FILE>init</FILE>
<TITLE>Initialization and Finalization</TITLE>
dh_init
-dh_free_resources
+dh_finalize
</SECTION>
<SECTION>
diff --git a/src/dh-init.h b/src/dh-init.h
index 6770787..6b91bb1 100644
--- a/src/dh-init.h
+++ b/src/dh-init.h
@@ -23,8 +23,8 @@
G_BEGIN_DECLS
-void dh_init (void);
-void dh_free_resources (void);
+void dh_init (void);
+void dh_finalize (void);
G_END_DECLS
diff --git a/src/dh-main.c b/src/dh-main.c
index d10e53c..1acaa4e 100644
--- a/src/dh-main.c
+++ b/src/dh-main.c
@@ -41,7 +41,7 @@ main (int argc, char **argv)
status = g_application_run (G_APPLICATION (application), argc, argv);
g_object_unref (application);
- dh_free_resources ();
+ dh_finalize ();
return status;
}
[
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]
diff --git a/src/dh-init.c b/src/dh-init.c
index d0d129c..a0a0b7e 100644
--- a/src/dh-init.c
+++ b/src/dh-init.c
@@ -44,7 +44,7 @@ dh_init (void)
}
/**
- * dh_free_resources:
+ * dh_finalize:
*
* Free the resources allocated by Devhelp. For example it unrefs the singleton
* objects.
@@ -58,7 +58,7 @@ dh_init (void)
/* Another way is to use a DSO destructor, see gconstructor.h in GLib.
*
* The advantage of calling dh_free_resources() at the end of main() is that
* gobject-list [1] correctly reports that all Dh* objects have been finalized
* when quitting the application. On the other hand a DSO destructor runs after
* the gobject-list's last output, so it's much less convenient, see:
@@ -68,7 +68,7 @@ dh_init (void)
* https://github.com/danni/gobject-list
*/
void
-dh_free_resources (void)
+dh_finalize (void)
{
static gboolean done = FALSE;
@@ -58,7 +58,7 @@ dh_init (void)
/* Another way is to use a DSO destructor, see gconstructor.h in GLib.
*
- * The advantage of calling dh_free_resources() at the end of main() is that
+ * The advantage of calling dh_finalize() at the end of main() is that
* gobject-list [1] correctly reports that all Dh* objects have been finalized
* when quitting the application. On the other hand a DSO destructor runs after